@@ -1,19 +1,29 @@
 from firstimpression.constants import TEMP_FOLDER
 from firstimpression.constants import APIS
+from firstimpression.constants import LOCAL_INTEGRATED_FOLDER
 from firstimpression.file import download_install_media
 from firstimpression.file import update_directories_api
 from firstimpression.file import check_too_old
 from firstimpression.file import write_root_to_xml_files
+from firstimpression.file import xml_to_root
 from firstimpression.xml import get_xml
 from firstimpression.scala import log
+from firstimpression.scala import variables
 from logging import _nameToLevel
 import xml.etree.ElementTree as ET
 import os
+import glob
+
+##################################################################################################
+# CONSTANTS
+##################################################################################################
 
 NAME = APIS['amber']
 XML_FILENAME = 'amber_alert.xml'
+XML_FILENAME_CONTENT = 'amber_alert*.xml'
 URL = 'https://media.amberalert.nl/xml/combined/index.xml'
 XML_TEMP_PATH = os.path.join(TEMP_FOLDER, NAME, XML_FILENAME)
+XML_LOCAL_PATH = os.path.join(LOCAL_INTEGRATED_FOLDER, NAME, XML_FILENAME_CONTENT)
 URL_LOGO = 'http://fimp.nl/narrowcasting/amberalert.png'
 
 MAX_FILE_AGE = 60 * 10
@@ -35,6 +45,10 @@ TAGS = {
     'image': 'NP:Media/NP:Image'
 }
 
+##################################################################################################
+# MAIN FUNCTIONS API
+##################################################################################################
+
 def run_api():
     update_directories_api(NAME)
     
@@ -56,7 +70,26 @@ def run_api():
     else:
         log(_nameToLevel['INFO'],'File not old enough to update')
 
+def check_api():
+    svars = variables()
 
+    file_path = glob.glob(XML_LOCAL_PATH)[0]
+
+    if check_too_old(file_path, MAX_FILE_AGE):
+        svars['skipscript'] = True
+    else:
+        svars['skipscript'] = False
+
+        amount_items = int(xml_to_root(file_path).get('alerts', '0'))
+        
+        svars['total_items'] = amount_items
+        
+        if amount_items == 0:
+            svars['skipscript'] = True
+
+##################################################################################################
+# MEDIA FUNCTIONS
+##################################################################################################
 
 def download_install_logo():
     download_install_media(URL_LOGO, TEMP_FOLDER, NAME)
@@ -64,6 +97,10 @@ def download_install_logo():
 def download_photo_child(url):
     return download_install_media(url, TEMP_FOLDER, NAME)
 
+##################################################################################################
+# GET FUNCTIONS
+##################################################################################################
+
 def get_alerts(root):
     return root.findall(TAGS['alert'], NAMESPACE_XML)
 
@@ -102,6 +139,10 @@ def get_photo_child(message):
     else:
         return download_photo_child(media_url)
 
+##################################################################################################
+# PARSE
+##################################################################################################
+
 def parse_alert(alert):
     item = ET.Element("item")
     ET.SubElement(item, "soort").text = get_alert_soort(alert)
